Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: Source/WebCore/platform/chromium/PopupListBox.h

Issue 13818030: Added primary input devices setting to blink to allow media queries for hover/pointer (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Review fixes Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/WebCore/page/Settings.in ('k') | Source/WebCore/platform/chromium/PopupListBox.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/WebCore/platform/chromium/PopupListBox.h
diff --git a/Source/WebCore/platform/chromium/PopupListBox.h b/Source/WebCore/platform/chromium/PopupListBox.h
index 6575aee77f72999c9d03fa5a57f623d4ebf57695..6d7a12fd1a02c64d4ae37f51496acf728c8143f9 100644
--- a/Source/WebCore/platform/chromium/PopupListBox.h
+++ b/Source/WebCore/platform/chromium/PopupListBox.h
@@ -81,9 +81,9 @@ struct PopupContainerSettings {
// Autocomplete popups are restricted, combo-boxes (select tags) aren't.
bool restrictWidthOfListBox;
// If the device is a touch screen we increase the height of menu items
// to make it easier to unambiguously touch them.
- bool deviceSupportsTouch;
+ bool primaryInputIncludesTouch;
};
class PopupContent {
« no previous file with comments | « Source/WebCore/page/Settings.in ('k') | Source/WebCore/platform/chromium/PopupListBox.cpp » ('j') | no next file with comments »
@@ -81,9 +81,9 @@ struct PopupContainerSettings {
// Autocomplete popups are restricted, combo-boxes (select tags) aren't.
bool restrictWidthOfListBox;
- // If the device is a touch screen we increase the height of menu items
+ // If the primary input includes a touch screen we increase the height of menu items
// to make it easier to unambiguously touch them.

Powered by Google App Engine
This is Rietveld 408576698